@@ -101,7 +101,7 @@ class MultivariateNormal(Relation):
         # Create a normalization relation
         norm_parameters = Relation(random_state=self.rs)
         if norm is None:
-            p = Parameter("norm", 1.0, [0., DEFAULT_NORM_MAX], label="norm")
+            p = Parameter("norm", 0.0, [0., DEFAULT_NORM_MAX], label="norm")
             norm_parameters.add_parameter(p)
         else:
             norm_parameters.add_parameter(norm)
@@ -394,8 +394,12 @@ class MultivariateNormal(Relation):
                 L = np.sum(L, axis=1)
             else:
                 L = np.prod(L, axis=1)
-        elif (log_scale and lnL_offset):
+        if lnL_offset is None:
+            lnL_offset = self.read_norm()
+        if log_scale:
             L += lnL_offset
+        else:
+            L *= np.exp(lnL_offset)
 
         return L
 
@@ -646,8 +650,8 @@ class MultivariateNormal(Relation):
             norm_max = db.attr_value("norm","max")
         except:
             warnings.warn(
-                "Warning: no normalization constant found. Assuming 1.0")
-            norm = 1.0
+                "Warning: no normalization constant found. Assuming 0.0")
+            norm = 0.0
             norm_max=DEFAULT_NORM_MAX
         # Load mu params
         mu = db.dset_value("mean")
