@@ -266,7 +266,8 @@ class Grid(object):
                                  scale=MV.scale,
                                  log_scale=True,
                                 )
-        lnL_norm /= np.sum(lnL_norm)
+        # Normalization of Q is handled by relative entropy alt
+        #lnL_norm /= np.sum(lnL_norm)
 
         # Calculate the kl divergence
         kl = relative_entropy_alt(self.L_norm, self.lnL_norm, lnL_norm)
@@ -448,7 +449,6 @@ class Grid(object):
                                               )
 
         X_scipy = MV.scipy_out.x.flatten()
-        '''
         if objective == "kl":
             # Still need a least squares fit for the normalization constant
             def lstsq_norm(X0):
@@ -458,9 +458,8 @@ class Grid(object):
                 return lstsq
             # Minimize this one
             norm_scipy_out = scipy.optimize.minimize(
-                    lstsq_norm,X_scipy[0],method="Nelder-Mead",bounds=[self.X_lims[0]])
+                    lstsq_norm,X_scipy[0],method=method,bounds=[self.X_lims[0]])
             X_scipy[0] = norm_scipy_out.x.flatten()
-        '''
                 
         MV.assign_guess(X_scipy)
         return MV
