@@ -887,7 +887,6 @@ class Mesh(object):
                                  indices=[index,jndex],
                                  log_scale=True,
                                 )
-
         # Calculate the kl divergence
         kl = relative_entropy_alt(L_mesh, lnL_mesh, lnL_norm)
         return kl
@@ -944,24 +943,24 @@ class Mesh(object):
             kl = np.empty((X.shape[0],len(MV._parameters)-self.ndim))
             # First consider the 1D kl divergences
             for i in range(self.ndim):
-                kl[:,i] = kl1d[:,i]
+                kl[:,MV.p_map["mu_%d"%i]-1] = kl1d[:,i]
             # The 2d kl divergences have a bearing on 5 different parameters
             for i in range(self.ndim):
                 for j in range(i):
-                    kl[:,MV.p_map["cor_%d_%d"%(i,j)]-self.ndim] = kl2d[:,i,j]
+                    kl[:,MV.p_map["cor_%d_%d"%(i,j)]-self.ndim-1] = kl2d[:,i,j]
         elif mode == "parameter":
             kl = np.zeros((X.shape[0],len(MV._parameters)))
             # First consider the 1D kl divergences
             for i in range(self.ndim):
-                kl[:,i] = kl1d[:,i]
-                kl[:,i+self.ndim] = kl1d[:,i]
+                kl[:,MV.p_map["mu_%d"%i]] = kl1d[:,i]
+                kl[:,MV.p_map["std_%d"%i]] = kl1d[:,i]
             # The 2d kl divergences have a bearing on 5 different parameters
             for i in range(self.ndim):
                 for j in range(i):
-                    kl[:,i] += kl2d[:,i,j]
-                    kl[:,i+self.ndim] += kl2d[:,i,j]
-                    kl[:,j] += kl2d[:,i,j]
-                    kl[:,j+self.ndim] += kl2d[:,i,j]
+                    kl[:,MV.p_map["mu_%d"%i]] += kl2d[:,i,j]
+                    kl[:,MV.p_map["std_%d"%i]] += kl2d[:,i,j]
+                    kl[:,MV.p_map["mu_%d"%j]] += kl2d[:,i,j]
+                    kl[:,MV.p_map["std_%d"%j]] += kl2d[:,i,j]
                     kl[:,MV.p_map["cor_%d_%d"%(i,j)]] = kl2d[:,i,j]
             # for each parameter, we want to use the average of the
             # kl divergences associated with that parameter.
@@ -1021,8 +1020,8 @@ class Mesh(object):
             L_test = np.log(L_test[keep].flatten())
             # Find maximum
             mu, sig = self.polyfit_mu_sig_1d(y_test, L_test, X[i+self.ndim], self.limits[i])
-            Xg[0,i] = mu
-            Xg[0,i+self.ndim] = sig
+            Xg[0,i+1] = mu
+            Xg[0,i+self.ndim+1] = sig
 
         # Generate 1D training guesses
         for i in range(self.ndim):
@@ -1046,13 +1045,13 @@ class Mesh(object):
 
             # fit training set 1
             mu, sig = self.polyfit_mu_sig_1d(y_train_1, L_train_1, X[i+self.ndim], self.limits[i])
-            Xg[1,i] = mu
-            Xg[1,i+self.ndim] = sig
+            Xg[1,i+1] = mu
+            Xg[1,i+self.ndim+1] = sig
 
             # fit training set 2
             mu, sig = self.polyfit_mu_sig_1d(y_train_2, L_train_2, X[i+self.ndim], self.limits[i])
-            Xg[2,i] = mu
-            Xg[2,i+self.ndim] = sig
+            Xg[2,i+1] = mu
+            Xg[2,i+self.ndim+1] = sig
 
         return Xg
 
@@ -1099,9 +1098,9 @@ class Mesh(object):
 
         if f_opt_param is None:
             def f_opt_param(X):
-                L = np.zeros(X.shape)
+                L = np.ones(X.shape)
                 k = MV.satisfies_constraints(X)
-                L[k] = np.power(self.nal_kl_div(MV,X=X[k],mode='parameter'),-1)
+                L[k,1:] = np.power(self.nal_kl_div(MV,X=X[k],mode='parameter')[:,1:],-1)
                 L[~k] = 0.
                 return L
 
@@ -1141,9 +1140,10 @@ class Mesh(object):
         while nguess < nwalk:
             # Generate new random guesses
             mu = np.average(Xg,axis=0)
-            sig = sig_multiplier*np.std(Xg,axis=0)
+            sig = sig_multiplier*np.std(Xg[:,1:],axis=0)
             sig[sig < sig_min] = sig_min
-            Xn = mu + MV.rs.randn(nwalk-nguess,Xg.shape[1])*sig
+            Xn = np.tile(mu,(nwalk-nguess,1))
+            Xn[:,1:] += MV.rs.randn(nwalk-nguess,sig.size)*sig
             #Xn = MV.sample_uniform_unconstrained(nwalk - nguess)
             k = MV.satisfies_constraints(Xn)
             Xk = Xn[k]
@@ -1203,11 +1203,11 @@ class Mesh(object):
         from scipy.stats import multivariate_normal
 
         # Use variance of guesses to determine jump scale
-        sig = np.std(cur, axis=0)
+        sig = np.std(cur, axis=0)[1:]
 
         # Generate parameter likelihood
         Lcur_p = f_opt_param(cur)
-        Lcur = np.prod(Lcur_p,axis=1)
+        Lcur = np.prod(Lcur_p[:,1:],axis=1)
 
         # Identify best guesses
         n_carry = int(carryover*nwalk)
@@ -1229,9 +1229,9 @@ class Mesh(object):
         p2 = MV.rs.choice(np.arange(Xb.shape[0]),size=nwalk,p=Lb)
         for i in range(nwalk):
             # Choose random parameter values
-            choices = np.empty(cur.shape[1],dtype=bool)
+            choices = np.zeros(cur.shape[1],dtype=bool)
             Lb_p_sum = Lb_p[p1[i]] + Lb_p[p2[i]]
-            for j in range(cur.shape[1]):
+            for j in range(1,cur.shape[1]):
                 choices[j] = MV.rs.choice(
                        [True,False],
                        p=[
@@ -1255,7 +1255,8 @@ class Mesh(object):
 
         ## Generate new steps ##
         # loop through each random walker
-        new = cur + MV.rs.randn(nwalk,cur.shape[1])*sig*sig_factor
+        new = np.copy(cur)
+        new[:,1:] += MV.rs.randn(nwalk,sig.size)*sig*sig_factor
         keep = MV.satisfies_constraints(new)
         new[~keep] = cur[~keep]
 
