@@ -327,6 +327,49 @@ def mu_cov_of_params(X,**kwargs):
     cov = cov_of_params(X,**kwargs)
     return mu, cov
 
+def params_of_mu_cov(mu, cov):
+    '''Reconstruct Gaussian vectorized parameters for given mu and covariance
+    Parameters
+    ----------
+    mu: array like, shape = (npts, ndim)
+        Input Array of mu values
+    cov: array like, shape = (npts, ndim, ndim)
+        Input Array of cov values
+    '''
+    # Protect against usage
+    if (len(mu.shape) == 1) and (len(cov.shape) == 2):
+        mu = mu[None,:]
+        cov = cov[None,:,:]
+    elif (len(mu.shape) != 2) or (len(cov.shape) != 3):
+        raise ValueError("mu or cov is not the right shape!")
+    # Identify useful information
+    n_gauss = mu.shape[0]
+    ndim = mu.shape[1]
+    n_param = n_param_of_ndim(ndim)
+    # Protect against usage
+    if cov.shape != (n_gauss, ndim, ndim):
+        raise ValueError("cov is not shape (n_gauss, ndim, ndim)")
+    # Initialize array
+    X = np.empty((n_gauss,n_param))
+    # Initialize normalization
+    X[:,0] = 0.0
+    # Insert mu values
+    X[:,1:ndim+1] = mu
+    # Insert std values
+    X[:,ndim+1:2*ndim+1] = np.sqrt(np.sum(cov*np.eye(ndim),axis=1))
+    ## Compute Correlation ##
+    cor = cor_of_cov(cov)
+    ## Insert Correlation Values ##
+    cor_index = 2*ndim +1
+    for i in range(ndim):
+        for j in range(i):
+            X[:,cor_index] = cor[:,i,j]
+            cor_index += 1
+    if not cor_index == n_param:
+        raise RuntimeError("Correlation matrix not extracted properly")
+    # And we're done!
+    return X
+
 def params_of_norm_mu_cov(norm, mu, cov):
     '''Reconstruct Gaussian vectorized parameters for given mu and covariance
     Parameters
